==> oci-2.21.4-py2.py3-none-any.whl: oci/log_analytics/models/delete_log_analytics_association_details.py <==
# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeleteLogAnalyticsAssociationDetails(object):
    """
    DeleteLogAnalyticsAssociationDetails
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DeleteLogAnalyticsAssociationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this DeleteLogAnalyticsAssociationDetails.
        :type compartment_id: str

        :param items:
            The value to assign to the items property of this DeleteLogAnalyticsAssociationDetails.
        :type items: list[DeleteLogAnalyticsAssociation]

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'items': 'list[DeleteLogAnalyticsAssociation]'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'items': 'items'
        }

        self._compartment_id = None
        self._items = None

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this DeleteLogAnalyticsAssociationDetails.
        compartmentId


        :return: The compartment_id of this DeleteLogAnalyticsAssociationDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DeleteLogAnalyticsAssociationDetails.
        compartmentId


        :param compartment_id: The compartment_id of this DeleteLogAnalyticsAssociationDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def items(self):
        """
        Gets the items of this DeleteLogAnalyticsAssociationDetails.
        list of rule entity association details


        :return: The items of this DeleteLogAnalyticsAssociationDetails.
        :rtype: list[DeleteLogAnalyticsAssociation]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this DeleteLogAnalyticsAssociationDetails.
        list of rule entity association details


        :param items: The items of this DeleteLogAnalyticsAssociationDetails.
        :type: list[DeleteLogAnalyticsAssociation]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other

==> oci-2.60.0-py2.py3-none-any.whl: oci/log_analytics/models/delete_log_analytics_association_details.py <==
# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeleteLogAnalyticsAssociationDetails(object):
    """
    The information required to delete a list of associations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DeleteLogAnalyticsAssociationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this DeleteLogAnalyticsAssociationDetails.
        :type compartment_id: str

        :param items:
            The value to assign to the items property of this DeleteLogAnalyticsAssociationDetails.
        :type items: list[oci.log_analytics.models.DeleteLogAnalyticsAssociation]

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'items': 'list[DeleteLogAnalyticsAssociation]'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'items': 'items'
        }

        self._compartment_id = None
        self._items = None

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this DeleteLogAnalyticsAssociationDetails.
        The compartment ID


        :return: The compartment_id of this DeleteLogAnalyticsAssociationDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DeleteLogAnalyticsAssociationDetails.
        The compartment ID


        :param compartment_id: The compartment_id of this DeleteLogAnalyticsAssociationDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def items(self):
        """
        Gets the items of this DeleteLogAnalyticsAssociationDetails.
        The information required to delete an association.


        :return: The items of this DeleteLogAnalyticsAssociationDetails.
        :rtype: list[oci.log_analytics.models.DeleteLogAnalyticsAssociation]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this DeleteLogAnalyticsAssociationDetails.
        The information required to delete an association.


        :param items: The items of this DeleteLogAnalyticsAssociationDetails.
        :type: list[oci.log_analytics.models.DeleteLogAnalyticsAssociation]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
